#include "FitEvent.h"   // a simple struct with a few variables
#include "ReadInput.h"  // a function to read data from a textfile

#include "TApplication.h"
#include "TH1.h"
#include "TCanvas.h"
#include "TBox.h"

#include <iostream>
#include <vector>

using namespace std;

int nlines = -1;

int InitVals(const char* filename);

int main(int argc, char* argv[]) {

  // Initialize
  TApplication theApp = TApplication("Analysis", &argc, argv);

  // Set the filename to get the input data
  char* filename = "bd_test.dat";
  std::cout << "Using filename "<<filename<<std::endl;

  // Call the function that does the drawing etc:
  int retval = InitVals(filename);

  // ====================   Problem 1:
  // The canvas "Initial values..." is supposed to show two
  // plots, but for me it shows only one, because the last 
  // histo gets cleared (I do not understand this). If I draw
  // something else (in the following if-statement), this is
  // last thing drawn and I do see my 2nd histo.
  if(0) {
    cout << "back in main..."<<endl;
    TCanvas tc("tmp","tmp",0,0,50,50);
    TBox box(25,25,45,45);
    box.Draw();
  }

  // Show the canvas.
  theApp.Run(kTRUE);
  //
  // =======================  Problem 2:
  //
  // If you now select "Save as canvas.eps" from the file menu and open
  // dbg.eps in ghostview, you see the plots being drawn but immediately
  // being cleared again. Same for ps-format.

  return retval;
}

int InitVals(const char* filename)
{
  // Read in input data from dat/bd_test.dat
  // A "FitEvent" is just a struct with a few datamembers
  vector<FitEvent> inputdata;
  ifstream inputfile;
  nlines=-1;  // # lines read from inputfile
  inputfile.open(TString("dat/")+filename);
  ReadInput(inputfile, inputdata, false);
  inputfile.close();
  // Done reading.

  // Create histograms...
  TH1F* Bd_Mass = new TH1F("Bd_Mass ","Bd Mass ", 30, 5,5.6);
  TH1F* Bd_Lifetime = new TH1F("Bd_Lifetime ","Bd Lifetime", 80,-0.05,0.15);
  // and fill them with the data we just read
  vector<FitEvent>::iterator it_input = inputdata.begin();
  for (Int_t no = 0; no<nlines; no++, it_input++) {

    double Mass = it_input->mass_b;
    double Lifetime = it_input->ctau_b;
    
    Bd_Mass->Fill(Mass,1);         // using weight 1.0 currently
    Bd_Lifetime->Fill(Lifetime,1); // using weight 1.0 currently
  }
  
  // Now draw them
  TCanvas* c_dbg = new TCanvas("dbg","debug",100,20,800,400);
  c_dbg->Divide(2,1);
  c_dbg->cd(1);
  Bd_Mass->Draw();
  c_dbg->cd(2);
  gPad->SetLogy();
  Bd_Lifetime->Draw();
  c_dbg->Update();

  // AT THIS POINT, for some reason, the second histogram isn't showing...

  return 0;
} // end InitVals
